@@ -18,13 +18,15 @@ sub call{
                 $post_json->{post_type} = "event";
                 $post_json->{event} = $event;
                 $post_json->{params} = [@args];
-                my($data,$ua,$tx) = $client->http_post($post_api,json=>$post_json);
-                if($tx->success){
-                    $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "](@args)上报成功");
-                }
-                else{
-                    $client->warn("插件[".__PACKAGE__ . "]事件[".$event."](@args)上报失败:" . encode("utf8",$tx->error->{message}));
-                } 
+                $client->http_post($post_api,json=>$post_json,sub{
+                    my($data,$ua,$tx) = @_;
+                    if($tx->success){
+                        $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "](@args)上报成功");
+                    }
+                    else{
+                        $client->warn("插件[".__PACKAGE__ . "]事件[".$event."](@args)上报失败:" . encode("utf8",$tx->error->{message}));
+                    } 
+                });
             }
             elsif($event =~ /^new_group|lose_group|new_friend|lose_friend|new_group_member|lose_group_member$/){
                 my $post_json = {};
@@ -81,10 +83,14 @@ sub call{
                         eval{$json = $tx->res->json};
                         if($@){$client->warn($@);return}
                         if(defined $json){
+                            #暂时先不启用format的属性
                             #{code=>0,reply=>"回复的消息",format=>"text"}
-                            if((!defined $json->{format}) or (defined $json->{format} and $json->{format} eq "text")){
-                                $msg->reply(Encode::encode("utf8",$json->{reply})) if defined $json->{reply};
-                            }
+                            #if((!defined $json->{format}) or (defined $json->{format} and $json->{format} eq "text")){
+                            #    $msg->reply(Encode::encode("utf8",$json->{reply})) if defined $json->{reply};
+                            #}
+
+                            $msg->reply(Encode::encode("utf8",$json->{reply})) if defined $json->{reply};
+                            $msg->reply_media(Encode::encode("utf8",$json->{media})) if defined $json->{media} and $json->{media} =~ /^https?:\/\//;
                         }
                     }
                     #elsif($tx->res->headers->content_type =~ m#image/#){
